@@ -293,6 +293,7 @@ class Transaction(RipplePrimitive):
             'OfferCancel': OfferCancelTransaction,
             'TrustSet': TrustSetTransaction,
             'AccountSet': AccountSetTransaction,
+            'SetRegularKey': SetRegularKeyTransaction
         }[data['TransactionType']]
         self.__class__ = subclass
 
@@ -617,6 +618,10 @@ class AccountSetTransaction(Transaction):
     pass
 
 
+class SetRegularKeyTransaction(Transaction):
+    pass
+
+
 class TransactionSubscriptionMessage(RipplePrimitive):
     """The data structure returned by the server when subscribing to
     transaction updates.
